@@ -6,4 +6,4 @@
 #'
 #' @format A tibble with 85 rows and 16 variables, as derived from the Excel file.
 #'
-"ABD_test_data1"
+"inTRW"
